@@ -1,7 +1,7 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.c,v 1.7 2006/01/09 16:30:20 richb Exp $
+/*  $Header$
  *
- *  Copyright (C) 2004-2006 Sami Pietila
+ *  Copyright (C) 2004-2008 Sami Pietila
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 #include "ce_parser.h"
 #include "limits.h"
-#include "extern.h"
 #include "calctool.h"
 
 /* TODO: This file is almost identical to lr-parser. */
@@ -39,7 +38,8 @@ ce_parse_(char *expression, int result[MP_SIZE], int flags)
 
     if (strlen(expression)) {
         parser_state.i = 0;
-        parser_state.buff = gc_strdup(expression);
+        parser_state.buff = strdup(expression);
+		v->math_error = 0;
         ret = ceparse();
         free(parser_state.buff);
     }
@@ -52,11 +52,16 @@ ce_parse_(char *expression, int result[MP_SIZE], int flags)
         if ((flags & ANS) != (parser_state.flags & ANS)) {
             return -EINVAL;
         }
+
+		if (v->math_error) {
+		  return v->math_error;
+		}
+
         if (flags & ANS) {
             memcpy(result, parser_state.ret, sizeof(int)*MP_SIZE);
         }
 
-        return(0);
+		return 0;
     }
 }
 
